@@ -58,11 +58,13 @@ static const dctool_command_t *g_commands[] = {
 	&dctool_help,
 	&dctool_version,
 	&dctool_list,
+	&dctool_scan,
 	&dctool_download,
 	&dctool_dump,
 	&dctool_parse,
 	&dctool_read,
 	&dctool_write,
+	&dctool_timesync,
 	&dctool_fwupdate,
 	NULL
 };
@@ -274,14 +276,7 @@ main (int argc, char *argv[])
 	dc_context_set_loglevel (context, loglevel);
 	dc_context_set_logfunc (context, logfunc, NULL);
 
-	if (command->config & DCTOOL_CONFIG_DESCRIPTOR) {
-		// Check mandatory arguments.
-		if (device == NULL && family == DC_FAMILY_NULL) {
-			message ("No device name or family type specified.\n");
-			exitcode = EXIT_FAILURE;
-			goto cleanup;
-		}
-
+	if (device != NULL || family != DC_FAMILY_NULL) {
 		// Search for a matching device descriptor.
 		status = dctool_descriptor_search (&descriptor, device, family, model);
 		if (status != DC_STATUS_SUCCESS) {
@@ -303,6 +298,13 @@ main (int argc, char *argv[])
 		}
 	}
 
+	// Check mandatory descriptor arguments.
+	if (command->config & DCTOOL_CONFIG_DESCRIPTOR && descriptor == NULL) {
+		message ("No device name or family type specified.\n");
+		exitcode = EXIT_FAILURE;
+		goto cleanup;
+	}
+
 	// Execute the command.
 	exitcode = command->run (argc, argv, context, descriptor);
 
