@@ -214,7 +214,7 @@ atomics_cobalt_parser_get_field (dc_parser_t *abstract, dc_field_type_t type, un
 				*((dc_divemode_t *) value) = DC_DIVEMODE_OC;
 				break;
 			case 1: // Closed Circuit
-				*((dc_divemode_t *) value) = DC_DIVEMODE_CC;
+				*((dc_divemode_t *) value) = DC_DIVEMODE_CCR;
 				break;
 			default:
 				return DC_STATUS_DATAFORMAT;
