@@ -46,13 +46,14 @@
 #endif
 #endif
 
-#include "bluetooth.h"
+#include <libdivecomputer/bluetooth.h>
 
 #include "common-private.h"
 #include "context-private.h"
 #include "iostream-private.h"
 #include "iterator-private.h"
 #include "descriptor-private.h"
+#include "platform.h"
 
 #ifdef _WIN32
 #define DC_ADDRESS_FORMAT "%012I64X"
@@ -98,17 +99,17 @@ static const dc_iterator_vtable_t dc_bluetooth_iterator_vtable = {
 static const dc_iostream_vtable_t dc_bluetooth_vtable = {
 	sizeof(dc_socket_t),
 	dc_socket_set_timeout, /* set_timeout */
-	dc_socket_set_latency, /* set_latency */
-	dc_socket_set_break, /* set_break */
-	dc_socket_set_dtr, /* set_dtr */
-	dc_socket_set_rts, /* set_rts */
-	dc_socket_get_lines, /* get_lines */
-	dc_socket_get_available, /* get_received */
-	dc_socket_configure, /* configure */
+	NULL, /* set_latency */
+	NULL, /* set_break */
+	NULL, /* set_dtr */
+	NULL, /* set_rts */
+	NULL, /* get_lines */
+	dc_socket_get_available, /* get_available */
+	NULL, /* configure */
 	dc_socket_read, /* read */
 	dc_socket_write, /* write */
-	dc_socket_flush, /* flush */
-	dc_socket_purge, /* purge */
+	NULL, /* flush */
+	NULL, /* purge */
 	dc_socket_sleep, /* sleep */
 	dc_socket_close, /* close */
 };
@@ -311,6 +312,12 @@ dc_bluetooth_iterator_new (dc_iterator_t **out, dc_context_t *context, dc_descri
 		return DC_STATUS_NOMEMORY;
 	}
 
+	// Initialize the socket library.
+	status = dc_socket_init (context);
+	if (status != DC_STATUS_SUCCESS) {
+		goto error_free;
+	}
+
 #ifdef _WIN32
 	WSAQUERYSET wsaq;
 	memset(&wsaq, 0, sizeof (wsaq));
@@ -327,7 +334,7 @@ dc_bluetooth_iterator_new (dc_iterator_t **out, dc_context_t *context, dc_descri
 		} else {
 			SYSERROR (context, errcode);
 			status = dc_socket_syserror(errcode);
-			goto error_free;
+			goto error_socket_exit;
 		}
 	}
 
@@ -339,7 +346,7 @@ dc_bluetooth_iterator_new (dc_iterator_t **out, dc_context_t *context, dc_descri
 		s_errcode_t errcode = S_ERRNO;
 		SYSERROR (context, errcode);
 		status = dc_socket_syserror(errcode);
-		goto error_free;
+		goto error_socket_exit;
 	}
 
 	// Open a socket to the bluetooth adapter.
@@ -348,7 +355,7 @@ dc_bluetooth_iterator_new (dc_iterator_t **out, dc_context_t *context, dc_descri
 		s_errcode_t errcode = S_ERRNO;
 		SYSERROR (context, errcode);
 		status = dc_socket_syserror(errcode);
-		goto error_free;
+		goto error_socket_exit;
 	}
 
 	// Perform the bluetooth device discovery. The inquiry lasts for at
@@ -378,6 +385,8 @@ dc_bluetooth_iterator_new (dc_iterator_t **out, dc_context_t *context, dc_descri
 error_close:
 	hci_close_dev(fd);
 #endif
+error_socket_exit:
+	dc_socket_exit (context);
 error_free:
 	dc_iterator_deallocate ((dc_iterator_t *) iterator);
 	return status;
@@ -485,6 +494,7 @@ dc_bluetooth_iterator_free (dc_iterator_t *abstract)
 	bt_free(iterator->devices);
 	hci_close_dev(iterator->fd);
 #endif
+	dc_socket_exit (abstract->context);
 
 	return DC_STATUS_SUCCESS;
 }
@@ -503,7 +513,7 @@ dc_bluetooth_open (dc_iostream_t **out, dc_context_t *context, dc_bluetooth_addr
 	INFO (context, "Open: address=" DC_ADDRESS_FORMAT ", port=%u", address, port);
 
 	// Allocate memory.
-	device = (dc_socket_t *) dc_iostream_allocate (context, &dc_bluetooth_vtable);
+	device = (dc_socket_t *) dc_iostream_allocate (context, &dc_bluetooth_vtable, DC_TRANSPORT_BLUETOOTH);
 	if (device == NULL) {
 		SYSERROR (context, S_ENOMEM);
 		return DC_STATUS_NOMEMORY;
