@@ -42,7 +42,7 @@
 #endif
 #endif
 
-#include "irda.h"
+#include <libdivecomputer/irda.h>
 
 #include "common-private.h"
 #include "context-private.h"
@@ -91,17 +91,17 @@ static const dc_iterator_vtable_t dc_irda_iterator_vtable = {
 static const dc_iostream_vtable_t dc_irda_vtable = {
 	sizeof(dc_socket_t),
 	dc_socket_set_timeout, /* set_timeout */
-	dc_socket_set_latency, /* set_latency */
-	dc_socket_set_break, /* set_break */
-	dc_socket_set_dtr, /* set_dtr */
-	dc_socket_set_rts, /* set_rts */
-	dc_socket_get_lines, /* get_lines */
-	dc_socket_get_available, /* get_received */
-	dc_socket_configure, /* configure */
+	NULL, /* set_latency */
+	NULL, /* set_break */
+	NULL, /* set_dtr */
+	NULL, /* set_rts */
+	NULL, /* get_lines */
+	dc_socket_get_available, /* get_available */
+	NULL, /* configure */
 	dc_socket_read, /* read */
 	dc_socket_write, /* write */
-	dc_socket_flush, /* flush */
-	dc_socket_purge, /* purge */
+	NULL, /* flush */
+	NULL, /* purge */
 	dc_socket_sleep, /* sleep */
 	dc_socket_close, /* close */
 };
@@ -300,7 +300,7 @@ dc_irda_open (dc_iostream_t **out, dc_context_t *context, unsigned int address,
 	INFO (context, "Open: address=%08x, lsap=%u", address, lsap);
 
 	// Allocate memory.
-	device = (dc_socket_t *) dc_iostream_allocate (context, &dc_irda_vtable);
+	device = (dc_socket_t *) dc_iostream_allocate (context, &dc_irda_vtable, DC_TRANSPORT_IRDA);
 	if (device == NULL) {
 		SYSERROR (context, S_ENOMEM);
 		return DC_STATUS_NOMEMORY;
