@@ -27,7 +27,6 @@
 #include "mares_common.h"
 #include "context-private.h"
 #include "device-private.h"
-#include "serial.h"
 #include "checksum.h"
 #include "array.h"
 
@@ -47,7 +46,6 @@ typedef struct mares_puck_device_t {
 static dc_status_t mares_puck_device_set_fingerprint (dc_device_t *abstract, const unsigned char data[], unsigned int size);
 static dc_status_t mares_puck_device_dump (dc_device_t *abstract, dc_buffer_t *buffer);
 static dc_status_t mares_puck_device_foreach (dc_device_t *abstract, dc_dive_callback_t callback, void *userdata);
-static dc_status_t mares_puck_device_close (dc_device_t *abstract);
 
 static const dc_device_vtable_t mares_puck_device_vtable = {
 	sizeof(mares_puck_device_t),
@@ -58,7 +56,7 @@ static const dc_device_vtable_t mares_puck_device_vtable = {
 	mares_puck_device_dump, /* dump */
 	mares_puck_device_foreach, /* foreach */
 	NULL, /* timesync */
-	mares_puck_device_close /* close */
+	NULL /* close */
 };
 
 static const mares_common_layout_t mares_puck_layout = {
@@ -87,7 +85,7 @@ static const mares_common_layout_t mares_nemowide_layout = {
 
 
 dc_status_t
-mares_puck_device_open (dc_device_t **out, dc_context_t *context, const char *name)
+mares_puck_device_open (dc_device_t **out, dc_context_t *context, dc_iostream_t *iostream)
 {
 	dc_status_t status = DC_STATUS_SUCCESS;
 	mares_puck_device_t *device = NULL;
@@ -103,45 +101,38 @@ mares_puck_device_open (dc_device_t **out, dc_context_t *context, const char *na
 	}
 
 	// Initialize the base class.
-	mares_common_device_init (&device->base);
+	mares_common_device_init (&device->base, iostream);
 
 	// Set the default values.
 	device->layout = NULL;
 	memset (device->fingerprint, 0, sizeof (device->fingerprint));
 
-	// Open the device.
-	status = dc_serial_open (&device->base.iostream, context, name);
-	if (status != DC_STATUS_SUCCESS) {
-		ERROR (context, "Failed to open the serial port.");
-		goto error_free;
-	}
-
 	// Set the serial communication protocol (38400 8N1).
 	status = dc_iostream_configure (device->base.iostream, 38400, 8, DC_PARITY_NONE, DC_STOPBITS_ONE, DC_FLOWCONTROL_NONE);
 	if (status != DC_STATUS_SUCCESS) {
 		ERROR (context, "Failed to set the terminal attributes.");
-		goto error_close;
+		goto error_free;
 	}
 
 	// Set the timeout for receiving data (1000 ms).
 	status = dc_iostream_set_timeout (device->base.iostream, 1000);
 	if (status != DC_STATUS_SUCCESS) {
 		ERROR (context, "Failed to set the timeout.");
-		goto error_close;
+		goto error_free;
 	}
 
 	// Clear the DTR line.
 	status = dc_iostream_set_dtr (device->base.iostream, 0);
 	if (status != DC_STATUS_SUCCESS) {
 		ERROR (context, "Failed to clear the DTR line.");
-		goto error_close;
+		goto error_free;
 	}
 
 	// Clear the RTS line.
 	status = dc_iostream_set_rts (device->base.iostream, 0);
 	if (status != DC_STATUS_SUCCESS) {
 		ERROR (context, "Failed to clear the RTS line.");
-		goto error_close;
+		goto error_free;
 	}
 
 	// Make sure everything is in a sane state.
@@ -151,7 +142,7 @@ mares_puck_device_open (dc_device_t **out, dc_context_t *context, const char *na
 	unsigned char header[PACKETSIZE] = {0};
 	status = mares_common_device_read ((dc_device_t *) device, 0, header, sizeof (header));
 	if (status != DC_STATUS_SUCCESS) {
-		goto error_close;
+		goto error_free;
 	}
 
 	// Override the base class values.
@@ -175,31 +166,12 @@ mares_puck_device_open (dc_device_t **out, dc_context_t *context, const char *na
 
 	return DC_STATUS_SUCCESS;
 
-error_close:
-	dc_iostream_close (device->base.iostream);
 error_free:
 	dc_device_deallocate ((dc_device_t *) device);
 	return status;
 }
 
 
-static dc_status_t
-mares_puck_device_close (dc_device_t *abstract)
-{
-	dc_status_t status = DC_STATUS_SUCCESS;
-	mares_puck_device_t *device = (mares_puck_device_t*) abstract;
-	dc_status_t rc = DC_STATUS_SUCCESS;
-
-	// Close the device.
-	rc = dc_iostream_close (device->base.iostream);
-	if (rc != DC_STATUS_SUCCESS) {
-		dc_status_set_error(&status, rc);
-	}
-
-	return status;
-}
-
-
 static dc_status_t
 mares_puck_device_set_fingerprint (dc_device_t *abstract, const unsigned char data[], unsigned int size)
 {
