@@ -38,6 +38,7 @@ extern "C" {
 typedef struct oceanic_common_layout_t {
 	// Memory size.
 	unsigned int memsize;
+	unsigned int highmem;
 	// Device info.
 	unsigned int cf_devinfo;
 	// Ringbuffer pointers.
@@ -55,6 +56,7 @@ typedef struct oceanic_common_layout_t {
 	// 12-bit values or two 16-bit values with each 4 bits padding).
 	unsigned int pt_mode_global;
 	unsigned int pt_mode_logbook;
+	unsigned int pt_mode_serial;
 } oceanic_common_layout_t;
 
 typedef struct oceanic_common_device_t {
@@ -65,6 +67,12 @@ typedef struct oceanic_common_device_t {
 	unsigned int multipage;
 } oceanic_common_device_t;
 
+typedef struct oceanic_common_device_vtable_t {
+	dc_device_vtable_t base;
+	dc_status_t (*logbook) (dc_device_t *device, dc_event_progress_t *progress, dc_buffer_t *logbook);
+	dc_status_t (*profile) (dc_device_t *device, dc_event_progress_t *progress, dc_buffer_t *logbook, dc_dive_callback_t callback, void *userdata);
+} oceanic_common_device_vtable_t;
+
 typedef unsigned char oceanic_common_version_t[PAGESIZE + 1];
 
 int
@@ -73,6 +81,12 @@ oceanic_common_match (const unsigned char *version, const oceanic_common_version
 void
 oceanic_common_device_init (oceanic_common_device_t *device);
 
+dc_status_t
+oceanic_common_device_logbook (dc_device_t *device, dc_event_progress_t *progress, dc_buffer_t *logbook);
+
+dc_status_t
+oceanic_common_device_profile (dc_device_t *device, dc_event_progress_t *progress, dc_buffer_t *logbook, dc_dive_callback_t callback, void *userdata);
+
 dc_status_t
 oceanic_common_device_set_fingerprint (dc_device_t *device, const unsigned char data[], unsigned int size);
 
