@@ -52,7 +52,7 @@
 #define NOPTY 1
 #endif
 
-#include "serial.h"
+#include <libdivecomputer/serial.h>
 
 #include "common-private.h"
 #include "context-private.h"
@@ -121,7 +121,7 @@ static const dc_iostream_vtable_t dc_serial_vtable = {
 	dc_serial_set_dtr, /* set_dtr */
 	dc_serial_set_rts, /* set_rts */
 	dc_serial_get_lines, /* get_lines */
-	dc_serial_get_available, /* get_received */
+	dc_serial_get_available, /* get_available */
 	dc_serial_configure, /* configure */
 	dc_serial_read, /* read */
 	dc_serial_write, /* write */
@@ -268,14 +268,10 @@ dc_serial_open (dc_iostream_t **out, dc_context_t *context, const char *name)
 	if (out == NULL || name == NULL)
 		return DC_STATUS_INVALIDARGS;
 
-	// Are we using custom IO?
-	if (_dc_context_custom_io(context))
-		return dc_custom_io_serial_open(out, context, name);
-
 	INFO (context, "Open: name=%s", name);
 
 	// Allocate memory.
-	device = (dc_serial_t *) dc_iostream_allocate (context, &dc_serial_vtable);
+	device = (dc_serial_t *) dc_iostream_allocate (context, &dc_serial_vtable, DC_TRANSPORT_SERIAL);
 	if (device == NULL) {
 		SYSERROR (context, ENOMEM);
 		return DC_STATUS_NOMEMORY;
@@ -695,7 +691,7 @@ dc_serial_read (dc_iostream_t *abstract, void *data, size_t size, size_t *actual
 
 			if (init) {
 				// Calculate the initial timeout.
-				timeout = device->timeout * 1000;
+				timeout = (dc_usecs_t) device->timeout * 1000;
 				// Calculate the target time.
 				target = now + timeout;
 				init = 0;
