@@ -24,7 +24,7 @@
 #define NOGDI
 #include <windows.h>
 
-#include "serial.h"
+#include <libdivecomputer/serial.h>
 
 #include "common-private.h"
 #include "context-private.h"
@@ -91,7 +91,7 @@ static const dc_iostream_vtable_t dc_serial_vtable = {
 	dc_serial_set_dtr, /* set_dtr */
 	dc_serial_set_rts, /* set_rts */
 	dc_serial_get_lines, /* get_lines */
-	dc_serial_get_available, /* get_received */
+	dc_serial_get_available, /* get_available */
 	dc_serial_configure, /* configure */
 	dc_serial_read, /* read */
 	dc_serial_write, /* write */
@@ -260,10 +260,6 @@ dc_serial_open (dc_iostream_t **out, dc_context_t *context, const char *name)
 	if (out == NULL || name == NULL)
 		return DC_STATUS_INVALIDARGS;
 
-	// Are we using custom IO?
-	if (_dc_context_custom_io(context))
-		return dc_custom_io_serial_open(out, context, name);
-
 	INFO (context, "Open: name=%s", name);
 
 	// Build the device name.
@@ -280,7 +276,7 @@ dc_serial_open (dc_iostream_t **out, dc_context_t *context, const char *name)
 	}
 
 	// Allocate memory.
-	device = (dc_serial_t *) dc_iostream_allocate (context, &dc_serial_vtable);
+	device = (dc_serial_t *) dc_iostream_allocate (context, &dc_serial_vtable, DC_TRANSPORT_SERIAL);
 	if (device == NULL) {
 		SYSERROR (context, ERROR_OUTOFMEMORY);
 		return DC_STATUS_NOMEMORY;
