@@ -163,39 +163,6 @@ dc_socket_set_timeout (dc_iostream_t *abstract, int timeout)
 	return DC_STATUS_SUCCESS;
 }
 
-dc_status_t
-dc_socket_set_latency (dc_iostream_t *iostream, unsigned int value)
-{
-	return DC_STATUS_SUCCESS;
-}
-
-dc_status_t
-dc_socket_set_break (dc_iostream_t *iostream, unsigned int value)
-{
-	return DC_STATUS_SUCCESS;
-}
-
-dc_status_t
-dc_socket_set_dtr (dc_iostream_t *iostream, unsigned int value)
-{
-	return DC_STATUS_SUCCESS;
-}
-
-dc_status_t
-dc_socket_set_rts (dc_iostream_t *iostream, unsigned int value)
-{
-	return DC_STATUS_SUCCESS;
-}
-
-dc_status_t
-dc_socket_get_lines (dc_iostream_t *iostream, unsigned int *value)
-{
-	if (value)
-		*value = 0;
-
-	return DC_STATUS_SUCCESS;
-}
-
 dc_status_t
 dc_socket_get_available (dc_iostream_t *abstract, size_t *value)
 {
@@ -219,12 +186,6 @@ dc_socket_get_available (dc_iostream_t *abstract, size_t *value)
 	return DC_STATUS_SUCCESS;
 }
 
-dc_status_t
-dc_socket_configure (dc_iostream_t *abstract, unsigned int baudrate, unsigned int databits, dc_parity_t parity, dc_stopbits_t stopbits, dc_flowcontrol_t flowcontrol)
-{
-	return DC_STATUS_SUCCESS;
-}
-
 dc_status_t
 dc_socket_read (dc_iostream_t *abstract, void *data, size_t size, size_t *actual)
 {
@@ -333,20 +294,24 @@ out:
 	return status;
 }
 
-dc_status_t
-dc_socket_flush (dc_iostream_t *abstract)
-{
-	return DC_STATUS_SUCCESS;
-}
-
-dc_status_t
-dc_socket_purge (dc_iostream_t *abstract, dc_direction_t direction)
-{
-	return DC_STATUS_SUCCESS;
-}
-
 dc_status_t
 dc_socket_sleep (dc_iostream_t *abstract, unsigned int timeout)
 {
+#ifdef _WIN32
+	Sleep (timeout);
+#else
+	struct timespec ts;
+	ts.tv_sec  = (timeout / 1000);
+	ts.tv_nsec = (timeout % 1000) * 1000000;
+
+	while (nanosleep (&ts, &ts) != 0) {
+		int errcode = errno;
+		if (errcode != EINTR ) {
+			SYSERROR (abstract->context, errcode);
+			return dc_socket_syserror (errcode);
+		}
+	}
+#endif
+
 	return DC_STATUS_SUCCESS;
 }
